@@ -93,7 +93,7 @@ static bool boushi_valid(const boushi_t *b) {
 static const DBT DBT0;
 
 static const DBT boushi_deadlock0 = {
-	"boushi_deadlock", 15, 0, 0, 0, 0, 0
+	"boushi_deadlock", 15, 0, 0, 0, 0, DB_DBT_USERMEM
 };
 
 static const char *boushi_enomem = "Out of memory";
@@ -878,6 +878,7 @@ export bool boushi_put(boushi_t *b, const char *name, const void *buf, size_t le
 		key.data = path;
 		key.ulen =
 		key.size = pathlen + 1;
+		key.flags = DB_DBT_USERMEM;
 		val.data = &refcount;
 		val.ulen = sizeof refcount;
 		val.flags = DB_DBT_USERMEM;
@@ -1008,6 +1009,7 @@ export bool boushi_del(boushi_t *b, const char *name, bool *isfound) {
 			key.data = path;
 			key.ulen =
 			key.size = pathlen + 1;
+			key.flags = DB_DBT_USERMEM;
 			val.data = &refcount;
 			val.ulen = sizeof refcount;
 			val.flags = DB_DBT_USERMEM;
@@ -1160,6 +1162,7 @@ export bool boushi_get(boushi_t *b, const char *name, void **buf, size_t *len) {
 	key.data = sha1sum;
 	key.ulen =
 	key.size = sizeof sha1sum;
+	key.flags = DB_DBT_USERMEM;
 	val.flags = DB_DBT_MALLOC;
 	err = b->content->get(b->content, NULL, &key, &val, 0);
 
